@@ -198,6 +198,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -218,8 +220,8 @@ class AlbToFargate(
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
@@ -232,9 +234,9 @@ class AlbToFargate(
         listener_props: typing.Any = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
-        rule_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps] = None,
-        target_group_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+        target_group_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -258,6 +260,10 @@ class AlbToFargate(
         :param target_group_props: Optional custom properties for a new target group. While this is a standard attribute of props for ALB constructs, there are few pertinent properties for a Lambda target. Default: - none
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. Default: - none
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbToFargate.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AlbToFargateProps(
             public_api=public_api,
             alb_logging_bucket_props=alb_logging_bucket_props,
@@ -338,8 +344,8 @@ class AlbToFargateProps:
         self,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
@@ -352,9 +358,9 @@ class AlbToFargateProps:
         listener_props: typing.Any = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
-        rule_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps] = None,
-        target_group_props: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+        target_group_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC and ALB. Default: - none
@@ -386,6 +392,26 @@ class AlbToFargateProps:
             target_group_props = aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps(**target_group_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(AlbToFargateProps.__init__)
+            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
+            check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
+            check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
+            check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
+            check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
+            check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
+            check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
+            check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
+            check_type(argname="argument existing_load_balancer_obj", value=existing_load_balancer_obj, expected_type=type_hints["existing_load_balancer_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
+            check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
+            check_type(argname="argument listener_props", value=listener_props, expected_type=type_hints["listener_props"])
+            check_type(argname="argument load_balancer_props", value=load_balancer_props, expected_type=type_hints["load_balancer_props"])
+            check_type(argname="argument log_alb_access_logs", value=log_alb_access_logs, expected_type=type_hints["log_alb_access_logs"])
+            check_type(argname="argument rule_props", value=rule_props, expected_type=type_hints["rule_props"])
+            check_type(argname="argument target_group_props", value=target_group_props, expected_type=type_hints["target_group_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
